%* lsaf_printwarningmessage                                                    *;
%*                                                                             *;
%* Determines through user input if a warning message should be printed to     *;
%* to the log in the SAS Life Science Analytics Framework.                     *;
%*                                                                             *;
%* Called from any lsaf_xxx macro requiring suppression of Warning message.    *;
%* Returns _lsaf_PrintMessage_ containing the resolved message as a macro      *;
%* variable.                                                                   *;  
%*                                                                             *;
%* Syntax:                                                                     *;
%* %LSAF_PRINTWARNINGMESSAGE(LSAF_PRINTMESSAGE=lsaf-printmessage);             *;
%*                                                                             *;
%* @param lsaf_printmessage - optional - determines whether to print a WARNING *;
%*        message to the log. Values are 0 - do not print the WARNING to the   *;
%*        log and 1 - do print the WARNING to the log. Default is 1.           *;
%*                                                                             *;
%* @macrotype LSAF                                                             *;
%* @since 2.1                                                                  *;
%* @exposure internal                                                          *;
%*                                                                             *;
%* @history 2019-02-18  initial code                                           *;
%*                                                                             *;

%macro lsaf_printwarningmessage(lsaf_printmessage=1) /des='Print a warning message to the log for LSAF';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _lsaf_PrintMessage;
  %let message= %str(&_LSAF_PRODUCT_NAME_ Macro: * LSAF maximum query limit has been reached. More items may exist that satisfy the query. Refine the search.);
  %if &lsaf_printmessage ne 0 
    %then %let _lsaf_PrintMessage_= %str(WARNING: &message);
    %else %let _lsaf_PrintMessage_=%str(NOTE: &message);

%mend lsaf_printwarningmessage;